@@ -26,16 +26,16 @@ RSpec.describe Rack::Protection::XSSHeader do
   end
 
   it 'should not override the header if already set' do
-    mock_app with_headers('X-XSS-Protection' => '0')
+    mock_app with_headers('x-xss-protection' => '0')
     expect(get('/', {}, 'wants' => 'text/html').headers['X-XSS-Protection']).to eq('0')
   end
 
   it 'should set the X-Content-Type-Options' do
-    expect(get('/', {}, 'wants' => 'text/html').header['X-Content-Type-Options']).to eq('nosniff')
+    expect(get('/', {}, 'wants' => 'text/html').headers['X-Content-Type-Options']).to eq('nosniff')
   end
 
   it 'should set the X-Content-Type-Options for other content types' do
-    expect(get('/', {}, 'wants' => 'application/foo').header['X-Content-Type-Options']).to eq('nosniff')
+    expect(get('/', {}, 'wants' => 'application/foo').headers['X-Content-Type-Options']).to eq('nosniff')
   end
 
   it 'should allow changing the nosniff-mode off' do
@@ -48,7 +48,7 @@ RSpec.describe Rack::Protection::XSSHeader do
   end
 
   it 'should not override the header if already set X-Content-Type-Options' do
-    mock_app with_headers('X-Content-Type-Options' => 'sniff')
+    mock_app with_headers('x-content-type-options' => 'sniff')
     expect(get('/', {}, 'wants' => 'text/html').headers['X-Content-Type-Options']).to eq('sniff')
   end
 end
