@@ -4,6 +4,6 @@ module DummyApp
   def self.call(env)
     Thread.current[:last_env] = env
     body = (env['REQUEST_METHOD'] == 'HEAD' ? '' : 'ok')
-    [200, { 'Content-Type' => env['wants'] || 'text/plain' }, [body]]
+    [200, { 'content-type' => env['wants'] || 'text/plain' }, [body]]
   end
 end
