@@ -1,15 +1,16 @@
+# frozen_string_literal: true
+
 require 'sinatra/base'
 require 'sinatra/capture'
 
 module Sinatra
-
   # = Sinatra::ContentFor
   #
   # <tt>Sinatra::ContentFor</tt> is a set of helpers that allows you to capture
   # blocks inside views to be rendered later during the request. The most
   # common use is to populate different parts of your layout from your view.
   #
-  # The currently supported engines are: Erb, Erubi, Erubis, Haml and Slim.
+  # The currently supported engines are: Erb, Erubi, Haml and Slim.
   #
   # == Usage
   #
@@ -174,11 +175,11 @@ module Sinatra
     # for <tt>:head</tt>.
     def yield_content(key, *args, &block)
       if block_given? && !content_for?(key)
-        (haml? && Tilt[:haml] == Tilt::HamlTemplate) ? capture_haml(*args, &block) : yield(*args)
+        haml? && Tilt[:haml] == Tilt::HamlTemplate && respond_to?(:capture_haml) ? capture_haml(*args, &block) : yield(*args)
       else
         content = content_blocks[key.to_sym].map { |b| capture(*args, &b) }
         content.join.tap do |c|
-          if block_given? && (erb? || erubi? || erubis?)
+          if block_given? && (erb? || erubi?)
             @_out_buf << c
           end
         end
