@@ -1,10 +1,10 @@
 require 'spec_helper'
 
-describe Sinatra::ConfigFile do
+RSpec.describe Sinatra::ConfigFile do
   def config_file(*args, &block)
     mock_app do
       register Sinatra::ConfigFile
-      set :root, File.expand_path('../config_file', __FILE__)
+      set :root, File.expand_path('config_file', __dir__)
       instance_eval(&block) if block
       config_file(*args)
     end
