@@ -1,8 +1,6 @@
 $stderr.puts "loading"
 require 'sinatra'
 
-require_relative 'rainbows' if RUBY_ENGINE == 'ruby'
-
 configure do
   set :foo, :bar
 end
@@ -20,7 +18,7 @@ get '/stream' do
   stream do |out|
     sleep 0.1
     out << "a"
-    sleep 1.2
+    sleep 1.25
     out << "b"
   end
 end
@@ -37,7 +35,7 @@ end
 
 set :out, nil
 get '/async' do
-  stream(:keep_open) { |o| (settings.out = o) << "hi!" }
+  stream(:keep_open) { |o| (settings.out = o) << "hi!"; sleep 1 }
 end
 
 get '/send' do
@@ -66,7 +64,7 @@ end
 class Subclass < Sinatra::Base
   set :out, nil
   get '/subclass/async' do
-    stream(:keep_open) { |o| (settings.out = o) << "hi!" }
+    stream(:keep_open) { |o| (settings.out = o) << "hi!"; sleep 1 }
   end
 
   get '/subclass/send' do
