@@ -1,4 +1,4 @@
-require File.expand_path('helper', __dir__)
+require_relative 'test_helper'
 require File.expand_path('integration_helper', __dir__)
 
 # These tests start a real server and talk to it over TCP.
@@ -13,7 +13,7 @@ class IntegrationTest < Minitest::Test
   it('only extends main') { assert_equal "true", server.get("/mainonly") }
 
   it 'logs once in development mode' do
-    next if server.puma? or server.falcon? or server.rainbows? or RUBY_ENGINE == 'jruby'
+    next if server.puma? or server.falcon? or RUBY_ENGINE == 'jruby'
     random = "%064x" % Kernel.rand(2**256-1)
     server.get "/ping?x=#{random}"
     count = server.log.scan("GET /ping?x=#{random}").count
@@ -28,15 +28,17 @@ class IntegrationTest < Minitest::Test
 
   it 'streams' do
     next if server.webrick? or server.trinidad?
-    times, chunks = [Time.now], []
+    times, chunks = [Process.clock_gettime(Process::CLOCK_MONOTONIC)], []
     server.get_stream do |chunk|
       next if chunk.empty?
       chunks << chunk
-      times << Time.now
+      times << Process.clock_gettime(Process::CLOCK_MONOTONIC)
     end
     assert_equal ["a", "b"], chunks
-    assert times[1] - times[0] < 1
-    assert times[2] - times[1] > 1
+    int1 = (times[1] - times[0]).round 2
+    int2 = (times[2] - times[1]).round 2
+    assert_operator 1, :>, int1
+    assert_operator 1, :<, int2
   end
 
   it 'starts the correct server' do
@@ -47,7 +49,7 @@ class IntegrationTest < Minitest::Test
     }ix
 
     # because Net HTTP Server logs to $stderr by default
-    assert_match exp, server.log unless server.net_http_server? || server.rainbows?
+    assert_match exp, server.log unless server.net_http_server?
   end
 
   it 'does not generate warnings' do
