@@ -1,7 +1,7 @@
-require File.expand_path('../helper', __FILE__)
+require_relative 'test_helper'
 
 begin
-require 'sass'
+require 'sass-embedded'
 
 class ScssTest < Minitest::Test
   def scss_app(options = {}, &block)
@@ -16,7 +16,7 @@ class ScssTest < Minitest::Test
   it 'renders inline Scss strings' do
     scss_app { scss "#scss {\n  background-color: white; }\n" }
     assert ok?
-    assert_equal "#scss {\n  background-color: white; }\n", body
+    assert_equal "#scss {\n  background-color: white;\n}", body
   end
 
   it 'defaults content type to css' do
@@ -45,13 +45,13 @@ class ScssTest < Minitest::Test
   it 'renders .scss files in views path' do
     scss_app { scss :hello }
     assert ok?
-    assert_equal "#scss {\n  background-color: white; }\n", body
+    assert_equal "#scss {\n  background-color: white;\n}", body
   end
 
   it 'ignores the layout option' do
     scss_app { scss :hello, :layout => :layout2 }
     assert ok?
-    assert_equal "#scss {\n  background-color: white; }\n", body
+    assert_equal "#scss {\n  background-color: white;\n}", body
   end
 
   it "raises error if template not found" do
@@ -63,23 +63,23 @@ class ScssTest < Minitest::Test
     scss_app do
       scss(
         "#scss {\n  background-color: white;\n  color: black\n}",
-        :style => :compact
+        :style => :compressed
       )
     end
     assert ok?
-    assert_equal "#scss { background-color: white; color: black; }\n", body
+    assert_equal "#scss{background-color:#fff;color:#000}", body
   end
 
   it "passes default scss options to the scss engine" do
     mock_app do
-      set :scss, {:style => :compact} # default scss style is :nested
+      set :scss, {:style => :compressed} # default scss style is :expanded
       get('/') {
         scss("#scss {\n  background-color: white;\n  color: black;\n}")
       }
     end
     get '/'
     assert ok?
-    assert_equal "#scss { background-color: white; color: black; }\n", body
+    assert_equal "#scss{background-color:#fff;color:#000}", body
   end
 end
 
